import { AWSDeployment } from '@goldstack/infra-aws';
import { TerraformDeployment } from '@goldstack/utils-terraform';
import { Deployment } from '@goldstack/infra';
import { Package, Configuration } from '@goldstack/utils-package';
/**
 * The name of the lambda.
 *
 * @title Lambda Name
 */
declare type LambdaName = string;
/**
 * The domain name that the API should be deployed to (e.g. api.mysite.com)
 *
 * @title API Domain
 */
export declare type APIDomain = string;
/**
 * The domain name of the Route 53 hosted zone that the domain for this API should be added to.
 *
 * @title Hosted Zone Domain
 */
export declare type HostedZoneDomain = string;
export interface LambdaExpressDeployment extends Deployment, AWSDeployment, TerraformDeployment {
    lambdaName: LambdaName;
    apiDomain: APIDomain;
    hostedZoneDomain: HostedZoneDomain;
}
/**
 * Places where the lambda should be deployed to.
 *
 * @title Deployments
 */
export declare type LambdaExpressDeployments = LambdaExpressDeployment[];
/**
 *
 *
 * @title Lambda Infrastructure Configuration
 */
export interface LambdaExpressInfrastructureConfiguration {
    deployments: LambdaExpressDeployments;
}
/**
 * Configures deployments for the lambda.
 *
 * @title Lambda Configuration
 *
 */
export interface LambdaExpressConfiguration extends Configuration {
    infrastructure: LambdaExpressInfrastructureConfiguration;
}
/**
 * A lambda deployment for an express server.
 *
 * @title Lambda Express Package
 */
export interface LambdaExpressPackage extends Package {
    configuration: LambdaExpressConfiguration;
}
export {};
//# sourceMappingURL=LambdaExpressPackage.d.ts.map